@@ -4,6 +4,10 @@ import os
 
 UTILS_DIR_PATH = os.path.dirname(os.path.abspath(__file__))
 
+class KerasyImprementationWarning(Warning):
+    """Implementation problem. Developer will resolve it."""
+    pass
+
 from . import bio_utils
 from . import deep_utils
 from . import generic_utils
@@ -43,7 +47,7 @@ from .generic_utils import urlDecorate
 from .generic_utils import measure_complexity
 from .generic_utils import has_all_attrs
 from .generic_utils import has_not_attrs
-from .generic_utils import handle_random_state
+from .generic_utils import handleRandomState
 from .generic_utils import fout_args
 from .generic_utils import format_spec_create
 from .generic_utils import print_func_create
@@ -101,6 +105,7 @@ from .toydata_utils import generateWholeCakes
 from .toydata_utils import generateWhirlpool
 from .toydata_utils import generateSeq
 from .toydata_utils import generateSeq_embedded_Motif
+from .toydata_utils import generate_test_data
 
 from .training_utils import make_batches
 from .training_utils import train_test_split
